function [Hd, nBands, centerFrequencies] = design_filterbank_iir_octave(fBase, fs, BandsPerOctave, ~)
  %% [Hd, nBands, centerFrequencies] = design_filterbank_iir_octave(fBase, fs, BandsPerOctave, ~)
  % Designs an IIR filterbank using Matlab's fdesign.octave command.
  %
  % fBase: the base frequency of the filterbank.
  % fs: sample rate
  % BandsPerOctave: number of band-pass filter per octave
  
  % Derivation for nBands:
  %
  % fBase * 2.^(i/12) < fs/2
  % log_2(fBase) + i/12 < log2(fs/2)
  % i < 12*log2(fs/2) - log2(fBase)*12
  %nBands = floor(BandsPerOctave*log2(fs/2) - log2(fBase)*BandsPerOctave);
  %centerFrequencies = fBase * 2.^( (1:nBands) /BandsPerOctave);
  
  N = 2;           % Filter Order
  F0 = fBase;       % Center Frequency (Hz)
  f = fdesign.octave(BandsPerOctave,'Class 1','N,F0',N,F0,fs);
  
  F0 = validfrequencies(f);
  Nfc = length(F0);
  for i=1:Nfc,
    f.F0 = F0(i);
    Hd(i) = design(f,'butter');
  end
  
  centerFrequencies = F0;
  nBands = Nfc;
end