function [y, guitar, fs, Hd] = guitar_test_suite(config)
%% read input sample
[guitar, fs] = wavread(['input/' config.inputFile]);

guitar = guitar(1:round(length(guitar)/config.inputFraction)); % only a fraction

%% design filterbank
if strcmpi(config.filterbankType, 'octave')
  disp('creating IIR filterbank with fdesign.octave');
  design_filterbank = @design_filterbank_iir_octave;
elseif strcmpi(config.filterbankType, 'iir')
  disp('creating IIR filterbank with own algorithm');
  design_filterbank = @design_filterbank_iir;
elseif strcmpi(config.filterbankType, 'fir')
  disp('creating FIR filterbank with own algorithm');
  design_filterbank = @design_filterbank_fir;
else
  disp('no filterbank type specified. creating FIR filterbank');
  design_filterbank = @design_filterbank_fir;
end
tic
[Hd, nBands, centerFrequencies] = design_filterbank(config.fBase, fs, config.BandsPerOctave, config.filterDistribution, config.stopbandAttenuation);
toc
filterbank = struct();
filterbank.Hd = Hd;
filterbank.nBands = nBands;
filterbank.centerFrequencies = centerFrequencies;

fprintf('size of filterbank is %d\n', length(filterbank.Hd));

if config.plotFilterbank
  fprintf('\nopening fvtool to plot filterbank\n');
  fvtool(Hd, 'Analysis', 'grpdelay', 'Fs', fs, 'FrequencyScale', 'Log')
end

%% low-pass filter input
if config.preprocessLowpass 
  fprintf('\nlow-pass filtering the input signal\n');
  tic
  guitar = iir_lpf(guitar);
  toc
end

%% apply filterbank
bpX = apply_filterbank(guitar, config, filterbank, fs);

%% shift frequencies
bpXshifted = sola_pitch_shift(bpX, config.pitchshift, filterbank.centerFrequencies, fs);

%% merge bands if log scale
if strcmpi(config.mergeBandsBeforeShaping, 'full')
  bpY = sum(bpXshifted, 3);
else
  if strcmpi(config.filterDistribution, 'log')
    nSemitones = length(config.pitchshift);
    bpY = zeros([size(guitar, 1), size(guitar, 2), config.BandsPerOctave, nSemitones]);
    for i=1:filterbank.nBands
      k = mod(i-1, config.BandsPerOctave)+1;
      bpY(:,:,k,:) = bpY(:,:,k,:) + bpXshifted(:,:,i,:);
    end
  else
    bpY = bpXshifted;
  end
end

%% waveshape
y = filterbank_waveshaping(bpY, config.waveshaper);

%% write output

% get current time and date
dateTime = datestr(now);
dateTime = strrep(dateTime, ':', '');
dateTime = strrep(dateTime, '-', '');
dateTime = strrep(dateTime, ' ', '_');

% prepare string
if isempty(config.pitchshift), pitchshiftStr = 'no';
else pitchshiftStr = num2str(config.pitchshift); end

if isnumeric(config.groupDelayCompensation), groupDelayCompStr = num2str(config.groupDelayCompensation);
else groupDelayCompStr = config.groupDelayCompensation; end

inputfileStr = config.inputFile(1:end-4);

wavwrite(y, fs, sprintf('output/%s %s %s %s_filterbank %s %s_grpdelay %s_pitchshift.wav', ...
    dateTime, inputfileStr, config.filterbankType, num2str(config.BandsPerOctave),...
    func2str(config.waveshaper), groupDelayCompStr, pitchshiftStr));
  
%% play output
if(config.playOutput)
  sound(y, fs);
end