function y = iir_lpf(x)
%% y = iir_lpf(x)
% Returns a lowpassed signal y from the input signal x.
% The filter is a 4th order IIR filter designed with Matlab's cheby1 design
% method. The passband frequency is set to 0.06 pi, and the passband ripple
% is 1dB.

persistent Hd;

if isempty(Hd)
  
  N     = 4;    % Order
  Fpass = 0.06;  % Passband Frequency
  Apass = 1;    % Passband Ripple (dB)
  
  h = fdesign.lowpass('n,fp,ap', N, Fpass, Apass);
  
  Hd = design(h, 'cheby1', ...
    'SOSScaleNorm', 'Linf');
  
  
  
  set(Hd,'PersistentMemory',true);
  
end

y = filter(Hd,x);


% [EOF]
