config = struct();

% input file must be a .wav file and be in the input/ subfolder.
config.inputFile = 'guitar_guestlist.wav';

% 1 will play the whole sample. 2 will only play the first half, 3 the first third etc.
config.inputFraction = 1; 

% Type of the filterbank. Either IIR, FIR or octave. octave will create an
% IIR filterband using Matlab's fdesign.octave function. octave is not
% recommended. FIR sounds best, but takes a long time to compute.
config.filterbankType = 'fir';

% choose between lin and log for FIR filters only. IIR filters will use
% the octave design that will automatically
config.filterDistribution = 'log';

% Base frequency of filter bank
config.fBase = 82.41;

% stopband attenuation in dB of each bandpass filter in the filterbank.
config.stopbandAttenuation = 10;

% opens fvtool to plot the filterbank if set to true
config.plotFilterbank = false;

% if set to true, the audio input is preprocessed using the iir_lpf method.
config.preprocessLowpass = false;

% if set to 'full', it will merge all bands for every semitone before
% waveshaping. Otherwise it will merge bands per octave if on log scale, or
% do nothing if on linear scale.
config.mergeBandsBeforeShaping = 'standard'; % full or standard

% defines the number of bandpass filters per octave
config.BandsPerOctave = 12;

% defines the amount of group delay compensation for the filter bank.
% Possible values are 'max', 'mean', 'none', or a number in ms.
% 'max' will compensate all group delay. 'mean' will calculate the average
% group delay of all filters and only compensate those bands that have a
% smaller group delay than this value. 'none' will turn off group delay
% compensation. You can also assign a number in ms as a maximum group delay
% compensation.
config.groupDelayCompensation = 'max';

% define a function for waveshaping. If you don't want any waveshaping at
% all, set it to:
% @(x) x;
config.waveshaper = @square_waveshaping;

% This array contains all pitch shifted versions. You have to explicitly
% include 0 in the array if you want to keep the original pitch.
% Example: [4 -12 0] will give you one major third over the original
% key, one octave below the original key and the original key itself.
config.pitchshift = [7 4 0 -24];

% if set to true, the resulting sound file is played back at the end of the
% filtering process. The file is saved to the output/ folder in any case.
% If playback fails due to some unforseen reason (soundcard broken), you
% can always recover the sound file from the output/ folder. Additionally,
% output samples and sampling rate will be saved in variables (see call of
% guitar_test_suite).
config.playOutput = true;

% Runs the test suite and saves the original signal to x, the waveshaped,
% pitch-transposed final result to x, the sampling rate to fs and the array
% of filters in the filterbank to Hd.
[y, x, fs, Hd] = guitar_test_suite(config);