function bpY = sola_pitch_shift(bpX, semitones, centerFrequencies, fs)
  %% bpY = sola_pitch_shift(bpX, semitones, centerFrequencies, fs)
  % this function takes a set of bandpassed input signals bpX and
  % frequency shifts them separately. It calls frequency_shift to do the
  % frequency shifting.
  %
  % bpX: array containing bandpassed signals. The array is
  % three-dimensional. Signals are expected to be column vectors, where
  % every column is one channel. The third dimension iterates over every
  % band, so that nBands = size(bpX, 3).
  %
  % semitones: array of semitones to pitch to. For example, [4 0 -12] will
  % shift the signal one third higher, one octave lower and also keep the
  % original pitch. Note that no filtering is applied and thus no quality 
  % is lost on the original pitch part (i.e. for an entry 0).
  %
  % centerFrequencies: Array that contains the centerFrequencies of every
  % bandpass component in bpX, so that the center frequency of bpX(:,:.i)
  % is centerFrequencies(i).
  %
  % fs: sampling rate of the input signal
  nSemitones = length(semitones);
  nBands = size(bpX, 3);
  bpY = zeros([size(bpX, 1), size(bpX, 2), nBands, nSemitones]);
  
  %% pitch shift
  tic
  fprintf('\npitch shifting bands\n');
  parfor i=1:nBands
    bpY(:,:,i, :) = frequency_shift(bpX(:,:,i), centerFrequencies(i), semitones, fs);
  end
  toc
end